@@ -3,12 +3,13 @@ import Clipboard from 'clipboard';
 import coreModule from '../core_module';
 import kbn from 'app/core/utils/kbn';
 import { appEvents } from 'app/core/core';
+import { AppEvents } from '@grafana/data';
 
 /** @ngInject */
-function tip($compile) {
+function tip($compile: any) {
   return {
     restrict: 'E',
-    link: (scope, elem, attrs) => {
+    link: (scope: any, elem: any, attrs: any) => {
       let _t =
         '<i class="grafana-tip fa fa-' +
         (attrs.icon || 'question-circle') +
@@ -26,7 +27,7 @@ function clipboardButton() {
     scope: {
       getText: '&clipboardButton',
     },
-    link: (scope, elem) => {
+    link: (scope: any, elem: any) => {
       scope.clipboard = new Clipboard(elem[0], {
         text: () => {
           return scope.getText();
@@ -34,7 +35,7 @@ function clipboardButton() {
       });
 
       scope.clipboard.on('success', () => {
-        appEvents.emit('alert-success', ['Content copied to clipboard']);
+        appEvents.emit(AppEvents.alertSuccess, ['Content copied to clipboard']);
       });
 
       scope.$on('$destroy', () => {
@@ -47,15 +48,15 @@ function clipboardButton() {
 }
 
 /** @ngInject */
-function compile($compile) {
+function compile($compile: any) {
   return {
     restrict: 'A',
-    link: (scope, element, attrs) => {
+    link: (scope: any, element: any, attrs: any) => {
       scope.$watch(
-        scope => {
+        (scope: any) => {
           return scope.$eval(attrs.compile);
         },
-        value => {
+        (value: any) => {
           element.html(value);
           $compile(element.contents())(scope);
         }
@@ -67,7 +68,7 @@ function compile($compile) {
 function watchChange() {
   return {
     scope: { onchange: '&watchChange' },
-    link: (scope, element) => {
+    link: (scope: any, element: any) => {
       element.on('input', () => {
         scope.$apply(() => {
           scope.onchange({ inputValue: element.val() });
@@ -78,10 +79,10 @@ function watchChange() {
 }
 
 /** @ngInject */
-function editorOptBool($compile) {
+function editorOptBool($compile: any) {
   return {
     restrict: 'E',
-    link: (scope, elem, attrs) => {
+    link: (scope: any, elem: any, attrs: any) => {
       const ngchange = attrs.change ? ' ng-change="' + attrs.change + '"' : '';
       const tip = attrs.tip ? ' <tip>' + attrs.tip + '</tip>' : '';
       const showIf = attrs.showIf ? ' ng-show="' + attrs.showIf + '" ' : '';
@@ -115,10 +116,10 @@ function editorOptBool($compile) {
 }
 
 /** @ngInject */
-function editorCheckbox($compile, $interpolate) {
+function editorCheckbox($compile: any, $interpolate: any) {
   return {
     restrict: 'E',
-    link: (scope, elem, attrs) => {
+    link: (scope: any, elem: any, attrs: any) => {
       const text = $interpolate(attrs.text)(scope);
       const model = $interpolate(attrs.model)(scope);
       const ngchange = attrs.change ? ' ng-change="' + attrs.change + '"' : '';
@@ -150,8 +151,8 @@ function editorCheckbox($compile, $interpolate) {
 }
 
 /** @ngInject */
-function gfDropdown($parse, $compile, $timeout) {
-  function buildTemplate(items, placement?) {
+function gfDropdown($parse: any, $compile: any, $timeout: any) {
+  function buildTemplate(items: any, placement?: any) {
     const upclass = placement === 'top' ? 'dropup' : '';
     const ul = ['<ul class="dropdown-menu ' + upclass + '" role="menu" aria-labelledby="drop1">', '</ul>'];
 
@@ -191,7 +192,7 @@ function gfDropdown($parse, $compile, $timeout) {
   return {
     restrict: 'EA',
     scope: true,
-    link: function postLink(scope, iElement, iAttrs) {
+    link: function postLink(scope: any, iElement: any, iAttrs: any) {
       const getter = $parse(iAttrs.gfDropdown),
         items = getter(scope);
       $timeout(() => {
