@@ -2,16 +2,21 @@ import * as d3 from 'd3';
 import * as d3ScaleChromatic from 'd3-scale-chromatic';
 
 export function getColorScale(colorScheme: any, lightTheme: boolean, maxValue: number, minValue = 0): (d: any) => any {
-  let colorInterpolator = d3ScaleChromatic[colorScheme.value];
-  let colorScaleInverted = colorScheme.invert === 'always' || (colorScheme.invert === 'dark' && !lightTheme);
+  //@ts-ignore
+  const colorInterpolator = d3ScaleChromatic[colorScheme.value];
+  const colorScaleInverted = colorScheme.invert === 'always' || colorScheme.invert === (lightTheme ? 'light' : 'dark');
 
-  let start = colorScaleInverted ? maxValue : minValue;
-  let end = colorScaleInverted ? minValue : maxValue;
+  const start = colorScaleInverted ? maxValue : minValue;
+  const end = colorScaleInverted ? minValue : maxValue;
 
   return d3.scaleSequential(colorInterpolator).domain([start, end]);
 }
 
-export function getOpacityScale(options, maxValue, minValue = 0) {
+export function getOpacityScale(
+  options: { cardColor?: null; colorScale?: any; exponent?: any },
+  maxValue: number,
+  minValue = 0
+) {
   let legendOpacityScale;
   if (options.colorScale === 'linear') {
     legendOpacityScale = d3
