@@ -1,13 +1,24 @@
 import coreModule from 'app/core/core_module';
 import locationUtil from 'app/core/utils/location_util';
+import { UrlQueryMap } from '@grafana/runtime';
+import { DashboardLoaderSrv } from 'app/features/dashboard/services/DashboardLoaderSrv';
+import { ILocationService } from 'angular';
+import { Scope, CoreEvents, AppEventEmitter } from 'app/types';
+import { backendSrv } from 'app/core/services/backend_srv';
 
 export class LoadDashboardCtrl {
   /** @ngInject */
-  constructor($scope, $routeParams, dashboardLoaderSrv, backendSrv, $location, $browser) {
-    $scope.appEvent('dashboard-fetch-start');
+  constructor(
+    $scope: Scope & AppEventEmitter,
+    $routeParams: UrlQueryMap,
+    dashboardLoaderSrv: DashboardLoaderSrv,
+    $location: ILocationService,
+    $browser: any
+  ) {
+    $scope.appEvent(CoreEvents.dashboardFetchStart);
 
     if (!$routeParams.uid && !$routeParams.slug) {
-      backendSrv.get('/api/dashboards/home').then(homeDash => {
+      backendSrv.get('/api/dashboards/home').then((homeDash: { redirectUri: string; meta: any }) => {
         if (homeDash.redirectUri) {
           const newUrl = locationUtil.stripBaseFromUrl(homeDash.redirectUri);
           $location.path(newUrl);
@@ -22,6 +33,7 @@ export class LoadDashboardCtrl {
 
     // if no uid, redirect to new route based on slug
     if (!($routeParams.type === 'script' || $routeParams.type === 'snapshot') && !$routeParams.uid) {
+      // @ts-ignore
       backendSrv.getDashboardBySlug($routeParams.slug).then(res => {
         if (res) {
           $location.path(locationUtil.stripBaseFromUrl(res.meta.url)).replace();
@@ -30,7 +42,7 @@ export class LoadDashboardCtrl {
       return;
     }
 
-    dashboardLoaderSrv.loadDashboard($routeParams.type, $routeParams.slug, $routeParams.uid).then(result => {
+    dashboardLoaderSrv.loadDashboard($routeParams.type, $routeParams.slug, $routeParams.uid).then((result: any) => {
       if (result.meta.url) {
         const url = locationUtil.stripBaseFromUrl(result.meta.url);
 
@@ -51,7 +63,7 @@ export class LoadDashboardCtrl {
 
 export class NewDashboardCtrl {
   /** @ngInject */
-  constructor($scope, $routeParams) {
+  constructor($scope: any, $routeParams: UrlQueryMap) {
     $scope.initDashboard(
       {
         meta: {
