@@ -8,7 +8,7 @@ export interface AlertRuleDTO {
   state: string;
   newStateDate: string;
   evalDate: string;
-  evalData?: object;
+  evalData?: { noData?: boolean; evalMatches?: any };
   executionError: string;
   url: string;
 }
@@ -16,9 +16,12 @@ export interface AlertRuleDTO {
 export interface AlertRule {
   id: number;
   dashboardId: number;
+  dashboardUid?: string;
+  dashboardSlug?: string;
   panelId: number;
   name: string;
   state: string;
+  newStateDate?: string;
   stateText: string;
   stateIcon: string;
   stateClass: string;
@@ -26,10 +29,12 @@ export interface AlertRule {
   url: string;
   info?: string;
   executionError?: string;
-  evalData?: { noData: boolean };
+  evalDate?: string;
+  evalData?: { noData?: boolean; evalMatches?: any };
 }
 
 export interface AlertRulesState {
   items: AlertRule[];
   searchQuery: string;
+  isLoading: boolean;
 }
